@@ -96,7 +96,8 @@ class htmlliteral(object):
         return self.text
 
     def __repr__(self):
-        return '<%s html=%r text=%r>' % (self.html, self.text)
+        return '<%s html=%r text=%r>' % (
+            self.__class__.__name__, self.html, self.text)
 
     def __html__(self):
         return self.html
@@ -166,6 +167,8 @@ class FillingParser(RewritingParser):
         <input type="checkbox" name="nice_guy">
     """
 
+    default_encoding = 'utf8'
+
     def __init__(self, defaults, errors=None, use_all_keys=False,
                  error_formatters=None, error_class='error',
                  add_attributes=None, listener=None,
@@ -213,9 +216,9 @@ class FillingParser(RewritingParser):
         if type(str1) == type(str2):
             return str1 == str2
         if isinstance(str1, unicode):
-            str1 = str1.encode(self.encoding)
+            str1 = str1.encode(self.encoding or self.default_encoding)
         else:
-            str2 = str2.encode(self.encoding)
+            str2 = str2.encode(self.encoding or self.default_encoding)
         return str1 == str2
 
     def close(self):
@@ -360,7 +363,8 @@ class FillingParser(RewritingParser):
             selected = False
             if not self.get_attr(attrs, 'value'):
                 selected = value
-            elif self.selected_multiple(value, self.get_attr(attrs, 'value')):
+            elif self.selected_multiple(value,
+                                        self.get_attr(attrs, 'value', '')):
                 selected = True
             if selected:
                 self.set_attr(attrs, 'checked', 'checked')
@@ -370,7 +374,7 @@ class FillingParser(RewritingParser):
             self.skip_next = True
             self.add_key(name)
         elif t == 'radio':
-            if self.str_compare(value, self.get_attr(attrs, 'value')):
+            if self.str_compare(value, self.get_attr(attrs, 'value', '')):
                 self.set_attr(attrs, 'checked', 'checked')
             else:
                 self.del_attr(attrs, 'checked')
@@ -386,8 +390,6 @@ class FillingParser(RewritingParser):
             self.skip_next = True
             self.add_key(name)
         elif t == 'image':
-            self.set_attr(attrs, 'src', value or
-                          self.get_attr(attrs, 'src', ''))
             self.write_tag('input', attrs, startend)
             self.skip_next = True
             self.add_key(name)
