@@ -196,8 +196,8 @@ class Schema(FancyValidator):
                     value_dict, state,
                     error_dict=errors)
 
-	    for validator in self.chained_validators:
-		new = validator.to_python(new, state)
+            for validator in self.chained_validators:
+                new = validator.to_python(new, state)
 
             return new
 
@@ -451,6 +451,9 @@ class SimpleFormValidator(FancyValidator):
         else:
             raise TypeError(
                 "Invalid error value: %r" % errors)
+        return value_dict
+
+    validate_partial = to_python
 
     def decorate(cls, **kw):
         def decorator(func):
