@@ -124,7 +124,7 @@ DecodeCase(AddressesForm,
 
 BadCase(AddressesForm,
         'addresses-1.name.fname=&addresses-1.name.lname=x&'
-        'addresses-1.email=x@x.com',
+        'addresses-1.email=x@domain.com',
         addresses=[d(name=d(fname="Please enter a value"))])
         
 BadCase(AddressesForm,
@@ -134,7 +134,7 @@ BadCase(AddressesForm,
 def test_this():
 
     for case in all_cases:
-        yield case.test
+        yield (case.test,)
 
 
 def test_merge():
@@ -149,4 +149,25 @@ def test_merge():
             == dict(a=['a1\naa1', 'a2'], b=['b\nbb', 'bbb'],
                     c=['c']))
 
+class ChainedTest(Schema):
+    a = validators.String()
+    a_confirm = validators.String()
 
+    b = validators.String()
+    b_confirm = validators.String()
+
+    chained_validators = [validators.FieldsMatch('a', 'a_confirm'),
+                            validators.FieldsMatch('b', 'b_confirm')]
+
+def test_multiple_chained_validators_errors():
+    s = ChainedTest()
+    try:
+        s.to_python({'a':'1', 'a_confirm':'2', 'b':'3', 'b_confirm':'4'})
+    except Invalid, e:
+        assert(e.error_dict.has_key('a_confirm') and e.error_dict.has_key('b_confirm'))
+    try:
+        s.to_python({})
+    except Invalid, e:
+        pass
+    else:
+        assert 0
